summaryrefslogtreecommitdiffstats
path: root/generic/tkImgBmap.c
diff options
context:
space:
mode:
Diffstat (limited to 'generic/tkImgBmap.c')
-rw-r--r--generic/tkImgBmap.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/generic/tkImgBmap.c b/generic/tkImgBmap.c
index cdd57dd..bbc471e 100644
--- a/generic/tkImgBmap.c
+++ b/generic/tkImgBmap.c
@@ -330,7 +330,7 @@ ImgBmapConfigureMaster(
* None.
*
* Side effects:
* Generates errors via Tcl_BackgroundError if there are problems in
* setting up the instance.
*
*----------------------------------------------------------------------
@@ -448,7 +448,7 @@ ImgBmapConfigureInstance(
Tcl_AppendObjToErrorInfo(masterPtr->interp, Tcl_ObjPrintf(
"\n (while configuring image \"%s\")", Tk_NameOfImage(
masterPtr->tkMaster)));
- Tcl_BackgroundError(masterPtr->interp);
+ Tcl_BackgroundException(masterPtr->interp, TCL_ERROR);
}
/*
@@ -330,7 +330,7 @@ ImgBmapConfigureMaster(
*
* Side effects:
- * Generates errors via Tcl_BackgroundError if there are problems in
+ * Generates errors via Tcl_BackgroundException if there are problems in
* setting up the instance.
*